import { McpServer } from "@modelcontextprotocol/sdk/server/mcp.js";
import pkg from "../../package.json" with { type: "json" };
/**
 * Makes a request to the Jasper AI API.
 * @param endpoint The API endpoint to hit (e.g., '/run-command').
 * @param method The HTTP method to use.
 * @param payload The request payload (optional, typically for POST/PUT/PATCH).
 * @returns Promise with the response data or null if the request fails.
 */
export default class JasperMcpServer extends McpServer {
    apiKey;
    apiBase;
    mcpSourceHeaderValue;
    constructor(apiKey, apiBase, mcpSourceHeaderValue) {
        super({
            name: "jasper-mcp-server",
            version: pkg.version,
            capabilities: {
                resources: {},
                tools: {},
            },
        });
        this.apiKey = apiKey;
        this.apiBase = apiBase;
        this.mcpSourceHeaderValue = mcpSourceHeaderValue;
    }
    async makeJasperRequest(endpoint, method, payload // Payload is now optional
    ) {
        const url = `${this.apiBase}${endpoint}`;
        const headers = {
            // Type headers for clarity
            "X-API-Key": this.apiKey,
            "X-MCP-Source": this.mcpSourceHeaderValue, // Custom tracking header
        };
        const fetchOptions = {
            // Type fetchOptions
            method,
            headers,
        };
        if (payload &&
            (method === "POST" || method === "PUT" || method === "PATCH")) {
            headers["Content-Type"] = "application/json";
            fetchOptions.body = JSON.stringify(payload);
        }
        const response = await fetch(url, fetchOptions);
        if (!response.ok) {
            let errorBody = null;
            try {
                errorBody = await response.json();
            }
            catch (e) {
                // Ignore
            }
            console.error(`Jasper API HTTP error! Status: ${response.status}, URL: ${url}, Method: ${method}, Response: ${JSON.stringify(errorBody || response.statusText)}`);
            throw new Error(`Jasper API HTTP error! Status: ${response.status}, Method: ${method}`);
        }
        // Handle cases where response might be empty (e.g., 204 No Content)
        const contentType = response.headers.get("content-type");
        if (response.status === 204 ||
            !contentType ||
            !contentType.includes("application/json")) {
            return null;
        }
        return (await response.json());
    }
}
