import { z } from "zod";
const applyStyleInputSchema = z.object({
    styleId: z.string().describe("The ID of the style to apply."),
    content: z.string().describe("The text content to style."),
});
/**
 * Registers a tool with the MCP server to apply a Jasper style to a given text content.
 * This implementation mirrors the structure of 'runCommand.ts'.
 */
export function registerApplyStyleTool(server) {
    server.registerTool("apply-style", {
        title: "Apply Style",
        description: "Applies a specified style guide's rules to the provided text content and returns the styled content. This tool can be used to ensure content conforms to the user's style guide, especially useful when generating content for public consumption or checking published content against the style guide.",
        inputSchema: {
            styleId: z.string().describe("The ID of the style to apply."),
            content: z.string().describe("The text content to style."),
        },
    }, async ({ styleId, content }) => {
        const endpoint = `/styles/${styleId}/apply`;
        const payload = { content };
        const result = await server.makeJasperRequest(endpoint, "POST", payload);
        if (!result) {
            return {
                content: [
                    {
                        type: "text",
                        text: `Failed to make request to Jasper AI for applyStyle. Result: ${JSON.stringify(result)}`,
                    },
                ],
            };
        }
        if (result.error) {
            return {
                content: [
                    {
                        type: "text",
                        text: `Jasper AI Error applying style: ${result.error}. Full response: ${JSON.stringify(result)}`,
                    },
                ],
            };
        }
        // Ensure data and output exist, and output is a string
        if (result.data) {
            return {
                content: [
                    {
                        type: "text",
                        text: result.data.text,
                    },
                ],
            };
        }
        else {
            // Handle unexpected response structure from Jasper API
            console.error("[applyStyleTool] Error: Unexpected response data structure from Jasper API:", result);
            return {
                content: [
                    {
                        type: "text",
                        text: `Style applied, but received an unexpected response format from Jasper AI. Response: ${JSON.stringify(result)}`,
                    },
                ],
            };
        }
    });
}
