import { z } from "zod";
/**
 * Registers the run-jasper-command tool with the MCP server.
 * This tool allows executing a command via the Jasper AI API.
 * @param server The MCP server instance.
 * @todo Confirm the actual Jasper AI endpoint for running commands.
 *
 
 */
const SEARCH_KNOWLEDGE_BASE_DESCRIPTION = `The Jasper Knowledge Base holds info about the user's company, industry, internal business (strategy docs, updates, etc.), and marketing content.

Use Jasper AI's /searchKnowledge endpoint to find relevant documents using short, Google-style keyword queries or phrases. This tool surfaces related documents; it does not answer questions directly.

Output modes:
- **knowledgeIds only**: For passing source docs to another tool (e.g., content generation). Example: "take the AGM meeting notes and turn it into an investor update"—request only knowledgeIds for generate-content.
- **Summaries**: For topic overviews. Example: "what do we know about customer X?"—request document summaries.
- **Full Text**: For specific details/answers. Example: "did we meet our targets last quarter?"—request full text of relevant docs.

Choose output (knowledgeIds, summaries, text, or any combination) to match your query. Queries should be general and discovery-oriented, not direct Q&A.`;
const SEARCH_KNOWLEDGE_BASE_INPUT_SCHEMA = {
    query: z.string().describe("The search query string."),
}; // Updated: only 'query' is required.
export function registerSearchKnowledgeBaseTool(server) {
    server.registerTool("search-knowledge-base", {
        title: "Search Knowledge Base",
        description: SEARCH_KNOWLEDGE_BASE_DESCRIPTION,
        inputSchema: SEARCH_KNOWLEDGE_BASE_INPUT_SCHEMA,
    }, async ({ query }) => {
        const endpoint = "/knowledge/search";
        const payload = { query };
        const result = await server.makeJasperRequest(endpoint, "POST", payload);
        if (!result) {
            return {
                content: [
                    {
                        type: "text",
                        text: "Failed to make request to Jasper AI for search-knowledge.",
                    },
                ],
            };
        }
        if (result.error) {
            return {
                content: [
                    {
                        type: "text",
                        text: `Jasper AI Error: ${result.error}`,
                    },
                ],
            };
        }
        // Format result.data as text for now (MCP text type)
        if (!result.data || !Array.isArray(result.data) || result.data.length === 0) {
            return {
                content: [
                    {
                        type: "text",
                        text: "No results.",
                    },
                ],
            };
        }
        return {
            content: result.data.map((item, idx) => {
                let parts = [
                    `Result ${idx + 1}:`,
                    `Name: ${item.name}`,
                    `ID: ${item.id}`,
                ];
                if (item.tags && Array.isArray(item.tags)) {
                    parts.push(`Tags: ${item.tags.join(", ")}`);
                }
                if (item.summary) {
                    parts.push(`Summary: ${item.summary}`);
                }
                if (item.relevantChunks && Array.isArray(item.relevantChunks)) {
                    item.relevantChunks.forEach((chunk, cidx) => {
                        parts.push(`Chunk ${cidx + 1} Score: ${chunk.score}`);
                        parts.push(`Chunk Content: ${chunk.content}`);
                    });
                }
                return {
                    type: "text",
                    text: parts.join("\n\n"),
                };
            }),
        };
    });
}
